module Page.Landing exposing
    ( Model
    , Msg
    , view
    , init
    , update
    , subscriptions
    )
import Element exposing (Element)
import Websockets
import Ports
import Json.Decode as Decode

type alias Model = {
    time : String
    }
type alias Landing = {
    time : String
    }
type Msg
    = ToFrontend Landing
    | DecodeError Decode.Error
    | NoOp

init : () -> Model
init flags = {
    time = "time not yet set"
    }

decodeToFrontend message =
    let
        decodeTime = Decode.field "time" Decode.string |> Decode.map Landing
        decodeLanding = Decode.field "Landing" decodeTime |> Decode.map ToFrontend
        decodedMessage = Decode.decodeString decodeLanding message
    in
        case decodedMessage of
            Ok decoded -> decoded
            Err err -> DecodeError err

subscriptions : Model -> Sub Msg
subscriptions model =
    Ports.socketOnEvent
        (Websockets.EventHandlers
            (\_ -> NoOp)
            (\_ -> NoOp)
            (\_ -> NoOp)
            (\message -> (message.data |> decodeToFrontend))
            (\_ -> NoOp)
        )

update : Msg -> Model -> (Model, Cmd Msg)
update msg model =
    case msg of
        ToFrontend landing -> ( {model | time = landing.time}, Cmd.none )
        _ -> (model, Cmd.none)

view : Model -> Element Msg
view model =
    Element.column []
        [ Element.text "Landing",
          Element.text <| "Current time is : " ++ model.time
        ]
